<?php

namespace App\Http\Controllers;

use App\Models\PackagingList;
use App\Models\PackagingListOrder;
use App\Traits\GenerateRef;
use Illuminate\Http\Request;

class PackagingListController extends Controller
{
    use GenerateRef;

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index() {
        return PackagingList::with('packaging_list_orders.roll', 'design')->latest()->get();
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request) {
        $packagingList = new PackagingList();

        $packagingList->fill($request->except('packaging_list_orders'));
        $packagingList->sr_no = 'PI_'.$this->generateRef(new PackagingList);
        $packagingList->save();

        if ($request->has('packaging_list_orders')) {
            foreach ($request->packaging_list_orders as $od) {
                $newOd = PackagingListOrder::create($od);
                $newOd->packaging_list_id = $packagingList->id;
                $newOd->save();
            }
        }

        return $packagingList;
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\PackagingList  $packagingList
     * @return \Illuminate\Http\Response
     */
    public function show(PackagingList $packagingList) {
        return PackagingList::where('id', $packagingList->id)->with('packaging_list_orders.roll', 'design')->first();
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\PackagingList  $packagingList
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, PackagingList $packagingList) {

        $packagingList->fill($request->except('packaging_list_orders', 'sr_no', 'delete_packaging_list_ids'));
        $packagingList->save();

        if ($request->has('packaging_list_orders')) {
            foreach ($request->packaging_list_orders as $od) {
                if (isset($od['id'])) {
                    $oldOd = PackagingListOrder::find($od['id']);
                    $oldOd->fill($od);
                    $oldOd->packaging_list_id = $packagingList->id;
                    $oldOd->save();
                } else {
                    $newOd = PackagingListOrder::create($od);
                    $newOd->packaging_list_id = $packagingList->id;
                    $newOd->save();
                }
            }
        }

        if ($request->has('delete_packaging_list_ids')) {
            PackagingListOrder::query()->whereIn('id', $request->delete_packaging_list_ids)->delete();
        }


        return $packagingList;
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\PackagingList  $packagingList
     * @return \Illuminate\Http\Response
     */
    public function destroy(PackagingList $packagingList) {
        PackagingListOrder::where('packaging_list_id', $packagingList->id)->delete();
        return $packagingList->delete();
    }
}
