<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;

class UserController extends Controller
{
    public function index() {
        return User::latest()->get();
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request) {
        $user = new User();
        $user->fill($request->except('token', 'password'));
        if ($request->has('password')) {
            $user->password = bcrypt($request->password);
        }

        if ($request->hasFile('cv')) {
            $filename = $request->file('cv')->hashName();
            $request->file('cv')->storeAs(storage_path('app/public/cvs'), $filename);
            $user->cv = $filename;
        }

        $user->save();

        return $user;
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\User  $User
     * @return \Illuminate\Http\Response
     */
    public function show($id) {
        return User::where('id', $id)->first();
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\User  $User
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id) {
        $user = User::findOrFail($id);
        $user->fill($request->except('token', 'password'));
        if ($request->has('password')) {
            $user->password = bcrypt($request->password);
        }

        if ($request->hasFile('cv')) {
            $filename = $request->file('cv')->hashName();
            $request->file('cv')->storeAs(storage_path('app/public/cvs'), $filename);
            $user->cv = $filename;
        }

        $user->save();

        return $user;
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\User  $User
     * @return \Illuminate\Http\Response
     */
    public function destroy($id) {
        return User::find($id)->delete();
    }
}
