<?php

namespace App\Http\Controllers;

use App\Models\DesignMaster;
use App\Models\DesignMasterDetail;
use Illuminate\Http\Request;

class DesignMasterController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     */
    public function index() {
        return DesignMaster::with([
            'design_master_details.product',
            'designs',
            'supplier'
        ])->latest()->get();
    }

    /**
     * Store a newly created resource in storage.
     *
     */
    public function store(Request $request) {


        $designMaster = new DesignMaster();

        $designMaster->fill($request->except('design_master_details'));
        // Handle file upload
        if ($request->hasFile('warp_pattern_file')) {
            $file = $request->file('warp_pattern_file');
            $filename = time().'_'.$file->getClientOriginalName();
            $filePath = $file->storeAs('warp_patterns', $filename, 'public');

            // Save the file path in the transaction record
            $designMaster->warp_pattern_file = $filename;
        }
        if ($request->hasFile('weft_pattern_file')) {
            $file = $request->file('weft_pattern_file');
            $filename = time().'_'.$file->getClientOriginalName();
            $filePath = $file->storeAs('weft_patterns', $filename, 'public');

            // Save the file path in the transaction record
            $designMaster->weft_pattern_file = $filename;
        }
        $designMaster->save();

        if ($request->has('design_master_details')) {
            foreach ($request->design_master_details as $od) {
                $newOd = DesignMasterDetail::create($od);
                $newOd->design_master_id = $designMaster->id;
                $newOd->save();
            }
        }

        return $designMaster;
    }

    /**
     * Display the specified resource.
     *
     */
    public function show(DesignMaster $designMaster) {
        return DesignMaster::where('id', $designMaster->id)->with('design_master_details.product', 'designs',
            'supplier')->first();
    }

    /**
     * Update the specified resource in storage.
     *
     */
    public function update(Request $request, DesignMaster $designMaster) {

        $designMaster->fill($request->except('design_master_details', 'po_id', 'delete_design_master_detail_ids'));

        // Handle file upload
        if ($request->hasFile('warp_pattern_file')) {
            $file = $request->file('warp_pattern_file');
            $filename = time().'_'.$file->getClientOriginalName();
            $filePath = $file->storeAs('warp_patterns', $filename, 'public');

            // Save the file path in the transaction record
            $designMaster->warp_pattern_file = $filename;
        }
        if ($request->hasFile('weft_pattern_file')) {
            $file = $request->file('weft_pattern_file');
            $filename = time().'_'.$file->getClientOriginalName();
            $filePath = $file->storeAs('weft_patterns', $filename, 'public');

            // Save the file path in the transaction record
            $designMaster->weft_pattern_file = $filename;
        }
        $designMaster->save();


        if ($request->has('design_master_details')) {
            foreach ($request->design_master_details as $od) {
                if (isset($od['id'])) {
                    $oldOd = DesignMasterDetail::find($od['id']);
                    $oldOd->fill($od);
                    $oldOd->design_master_id = $designMaster->id;
                    $oldOd->save();
                } else {
                    $newOd = DesignMasterDetail::create($od);
                    $newOd->design_master_id = $designMaster->id;
                    $newOd->save();
                }
            }
        }

        if ($request->has('delete_design_master_detail_ids')) {
            DesignMasterDetail::query()->whereIn('id', $request->delete_design_master_detail_ids)->delete();
        }

        return $designMaster;
    }

    /**
     * Remove the specified resource from storage.
     *
     */
    public function destroy(DesignMaster $designMaster) {
        DesignMasterDetail::where('design_master_id', $designMaster->id)->delete();
        return $designMaster->delete();
    }
}
